Get under/over/bad colors of Colormap objects
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

`matplotlib.colors.Colormap` now has methods
`~.colors.Colormap.get_under`, `~.colors.Colormap.get_over`,
`~.colors.Colormap.get_bad` for the colors used for out-of-range and masked
values.
